@@ -41,8 +41,10 @@
 #include <libart_lgpl/art_gray_svp.h>
 #include <libart_lgpl/art_rgb_svp.h>
 #include <libart_lgpl/art_svp_wind.h>
+
 #include <libgnomeprint/gnome-font-private.h>
 #include <libgnomeprint/gnome-rfont.h>
+#include <libgnomeprint/art_rgba_svp.h>
 
 #define noGRF_VERBOSE
 #define noGRF_DEBUG
@@ -768,6 +770,15 @@ gnome_rfont_render_glyph_rgba8 (GnomeRFont *rfont, gint glyph,
 	g_return_if_fail (glyph >= 0);
 	g_return_if_fail (glyph < GRF_NUM_GLYPHS (rfont));
 
+	if (rfont->vector) {
+		const ArtSVP *svp;
+		svp = gnome_rfont_get_glyph_svp (rfont, glyph);
+		if (svp) {
+			gnome_print_art_rgba_svp_alpha (svp, -x, -y, width - x, height - y, rgba, buf, rowstride, NULL);
+		}
+		return;
+	}
+
 	slot = grf_ensure_slot_graymap (rfont, glyph);
 	g_return_if_fail (slot && slot->has_graymap);
 	if (slot->is_greek || !slot->bd.px)
