@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: ttcr.c,v 1.5 2004/10/13 00:28:08 mortenw Exp $ */
+/* $Id: ttcr.c 1945 2005-01-04 20:10:46Z jody $ */
 /* @(#)ttcr.c 1.7 03/01/08 SMI */
 
 /*
@@ -43,9 +43,12 @@
  * @version 1.3
  *
  */
+#include <config.h>
 
 #include <sys/types.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <fcntl.h>
 #include <stdlib.h>
 #ifdef sun
@@ -56,6 +59,10 @@
 #include <assert.h>
 #include "ttcr.h"
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 /* These must be #defined so that they can be used in initializers */
 #define T_maxp  0x6D617870
 #define T_glyf  0x676C7966
@@ -73,9 +80,9 @@
 #define T_cvt   0x63767420
 
 typedef struct {
-    uint32 tag;
-    uint32 length;
-    byte  *data;
+    guint32 tag;
+    guint32 length;
+    guint8  *data;
 } TableEntry;
 
 /*
@@ -87,14 +94,14 @@ typedef struct {
 #define _inline static
 #endif
 
-_inline uint32 mkTag(byte a, byte b, byte c, byte d) {
+_inline guint32 mkTag(guint8 a, guint8 b, guint8 c, guint8 d) {
     return (a << 24) | (b << 16) | (c << 8) | d;
 }
 
 /*- Data access macros for data stored in big-endian or little-endian format */
-_inline int16 GetInt16(const byte *ptr, size_t offset, int bigendian)
+_inline gint16 GetInt16(const guint8 *ptr, size_t offset, int bigendian)
 {
-    int16 t;
+    gint16 t;
     assert(ptr != 0);
     
     if (bigendian) {
@@ -106,9 +113,9 @@ _inline int16 GetInt16(const byte *ptr, size_t offset, int bigendian)
     return t;
 }
 
-_inline uint16 GetUInt16(const byte *ptr, size_t offset, int bigendian)
+_inline guint16 GetUInt16(const guint8 *ptr, size_t offset, int bigendian)
 {
-    uint16 t;
+    guint16 t;
     assert(ptr != 0);
 
     if (bigendian) {
@@ -120,9 +127,9 @@ _inline uint16 GetUInt16(const byte *ptr, size_t offset, int bigendian)
     return t;
 }
 
-_inline int32  GetInt32(const byte *ptr, size_t offset, int bigendian)
+_inline gint32  GetInt32(const guint8 *ptr, size_t offset, int bigendian)
 {
-    int32 t;
+    gint32 t;
     assert(ptr != 0);
     
     if (bigendian) {
@@ -136,9 +143,9 @@ _inline int32  GetInt32(const byte *ptr, size_t offset, int bigendian)
     return t;
 }
 
-_inline uint32 GetUInt32(const byte *ptr, size_t offset, int bigendian)
+_inline guint32 GetUInt32(const guint8 *ptr, size_t offset, int bigendian)
 {
-    uint32 t;
+    guint32 t;
     assert(ptr != 0);
     
 
@@ -154,7 +161,7 @@ _inline uint32 GetUInt32(const byte *ptr, size_t offset, int bigendian)
 }
 
 
-_inline void PutInt16(int16 val, byte *ptr, size_t offset, int bigendian)
+_inline void PutInt16(gint16 val, guint8 *ptr, size_t offset, int bigendian)
 {
     assert(ptr != 0);
 
@@ -168,7 +175,7 @@ _inline void PutInt16(int16 val, byte *ptr, size_t offset, int bigendian)
 
 }
 
-_inline void PutUInt16(uint16 val, byte *ptr, size_t offset, int bigendian)
+_inline void PutUInt16(guint16 val, guint8 *ptr, size_t offset, int bigendian)
 {
     assert(ptr != 0);
 
@@ -183,7 +190,7 @@ _inline void PutUInt16(uint16 val, byte *ptr, size_t offset, int bigendian)
 }
 
 
-_inline void PutUInt32(uint32 val, byte *ptr, size_t offset, int bigendian)
+_inline void PutUInt32(guint32 val, guint8 *ptr, size_t offset, int bigendian)
 {
     assert(ptr != 0);
 
@@ -202,7 +209,7 @@ _inline void PutUInt32(uint32 val, byte *ptr, size_t offset, int bigendian)
 }
 
 
-_inline void PutInt32(int32 val, byte *ptr, size_t offset, int bigendian)
+_inline void PutInt32(gint32 val, guint8 *ptr, size_t offset, int bigendian)
 {
     assert(ptr != 0);
 
@@ -243,10 +250,10 @@ static int NameRecordCompareF(const void *l, const void *r)
 }
     
 
-static uint32 CheckSum(uint32 *ptr, uint32 length)
+static guint32 CheckSum(guint32 *ptr, guint32 length)
 {
-    uint32 sum = 0;
-    uint32 *endptr = ptr + ((length + 3) & (uint32) ~3) / 4;
+    guint32 sum = 0;
+    guint32 *endptr = ptr + ((length + 3) & (guint32) ~3) / 4;
 
     while (ptr < endptr) sum += *ptr++;
 
@@ -271,7 +278,7 @@ _inline void *scalloc(size_t n, size_t size)
  * Public functions
  */
 
-void TrueTypeCreatorNewEmpty(uint32 tag, TrueTypeCreator **_this)
+void TrueTypeCreatorNewEmpty(guint32 tag, TrueTypeCreator **_this)
 {
     TrueTypeCreator *ptr = smalloc(sizeof(TrueTypeCreator));
 
@@ -297,7 +304,7 @@ int AddTable(TrueTypeCreator *_this, TrueTypeTable *table)
     return SF_OK;
 }
 
-void RemoveTable(TrueTypeCreator *_this, uint32 tag)
+void RemoveTable(TrueTypeCreator *_this, guint32 tag)
 {
     int done = 0;
     
@@ -317,15 +324,15 @@ void RemoveTable(TrueTypeCreator *_this, uint32 tag)
 
 static void ProcessTables(TrueTypeCreator *);
 
-int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
+int StreamToMemory(TrueTypeCreator *_this, guint8 **ptr, guint32 *length)
 {
-    uint16 numTables, searchRange=1, entrySelector=0, rangeShift;
-    uint32 s, offset, checkSumAdjustment = 0;
-    uint32 *p;
-    byte *ttf;
+    guint16 numTables, searchRange=1, entrySelector=0, rangeShift;
+    guint32 s, offset, checkSumAdjustment = 0;
+    guint32 *p;
+    guint8 *ttf;
     int i=0, n;
     TableEntry *te;
-    byte *head = NULL;     /* saved pointer to the head table data for checkSumAdjustment calculation */
+    guint8 *head = NULL;     /* saved pointer to the head table data for checkSumAdjustment calculation */
     
     if ((n = listCount(_this->tables)) == 0) return SF_TTFORMAT;
 
@@ -334,7 +341,7 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
     /* ProcessTables() adds 'loca' and 'hmtx' */
     
     n = listCount(_this->tables);
-    numTables = (uint16) n;
+    numTables = (guint16) n;
     
 
     te = scalloc(n, sizeof(TableEntry));
@@ -359,7 +366,7 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
     s = offset = 12 + 16 * n;
 
     for (i = 0; i < n; i++) {
-        s += (te[i].length + 3) & (uint32) ~3;
+        s += (te[i].length + 3) & (guint32) ~3;
         /* if ((te[i].length & 3) != 0) s += (4 - (te[i].length & 3)) & 3; */
     }
 
@@ -375,7 +382,7 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
     /* Table Directory */
     for (i = 0; i < n; i++) {
         PutUInt32(te[i].tag, ttf + 12, 16 * i, 1);
-        PutUInt32(CheckSum((uint32 *) te[i].data, te[i].length), ttf + 12, 16 * i + 4, 1);
+        PutUInt32(CheckSum((guint32 *) te[i].data, te[i].length), ttf + 12, 16 * i + 4, 1);
         PutUInt32(offset, ttf + 12, 16 * i + 8, 1);
         PutUInt32(te[i].length, ttf + 12, 16 * i + 12, 1);
 
@@ -383,14 +390,14 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
             head = ttf + offset;
         }
 
-        memcpy(ttf+offset, te[i].data, (te[i].length + 3) & (uint32) ~3 );
-        offset += (te[i].length + 3) & (uint32) ~3;
+        memcpy(ttf+offset, te[i].data, (te[i].length + 3) & (guint32) ~3 );
+        offset += (te[i].length + 3) & (guint32) ~3;
         /* if ((te[i].length & 3) != 0) offset += (4 - (te[i].length & 3)) & 3; */
     }
 
     free(te);
 
-    p = (uint32 *) ttf;
+    p = (guint32 *) ttf;
     for (i = 0; i < s / 4; i++) checkSumAdjustment += p[i];
     PutUInt32(0xB1B0AFBA - checkSumAdjustment, head, 8, 1);
 
@@ -402,12 +409,12 @@ int StreamToMemory(TrueTypeCreator *_this, byte **ptr, uint32 *length)
 
 int StreamToFile(TrueTypeCreator *_this, const char* fname)
 {
-    byte *ptr;
-    uint32 length;
+    guint8 *ptr;
+    guint32 length;
     int fd, r;
 
     if (!fname) return SF_BADFILE;
-    if ((fd = open(fname, O_WRONLY | O_CREAT | O_TRUNC, 0644)) == -1) return SF_BADFILE;
+    if ((fd = open(fname, O_WRONLY | O_BINARY | O_CREAT | O_TRUNC, 0644)) == -1) return SF_BADFILE;
 
     if ((r = StreamToMemory(_this, &ptr, &length)) != SF_OK) return r;
 
@@ -454,47 +461,47 @@ int StreamToFile(TrueTypeCreator *_this, const char* fname)
 #define CMAP_PAIR_INCR 500
 
 typedef struct {
-    uint32  id;                         /* subtable ID (platform/encoding ID)    */
-    uint32  n;                          /* number of used translation pairs      */
-    uint32  m;                          /* number of allocated translation pairs */
-    uint32 *xc;                         /* character array                       */
-    uint32 *xg;                         /* glyph array                           */
+    guint32  id;                         /* subtable ID (platform/encoding ID)    */
+    guint32  n;                          /* number of used translation pairs      */
+    guint32  m;                          /* number of allocated translation pairs */
+    guint32 *xc;                         /* character array                       */
+    guint32 *xg;                         /* glyph array                           */
 } CmapSubTable;
 
 typedef struct {
-    uint32 n;                           /* number of used CMAP sub-tables       */
-    uint32 m;                           /* number of allocated CMAP sub-tables  */
+    guint32 n;                           /* number of used CMAP sub-tables       */
+    guint32 m;                           /* number of allocated CMAP sub-tables  */
     CmapSubTable *s;                    /* sotred array of sub-tables           */
 } table_cmap;
 
 typedef struct {
-    uint32 tag;
-    uint32 nbytes;
-    byte *ptr;
+    guint32 tag;
+    guint32 nbytes;
+    guint8 *ptr;
 } tdata_generic;
 
 typedef struct {
-    uint32 nbytes;                      /* number of bytes in loca table */
-    byte *ptr;                          /* pointer to the data */
+    guint32 nbytes;                      /* number of bytes in loca table */
+    guint8 *ptr;                          /* pointer to the data */
 } tdata_loca;
 
 typedef struct {
-    uint32 format;
-    uint32 italicAngle;
-    int16  underlinePosition;
-    int16  underlineThickness;
-    uint32 isFixedPitch;
+    guint32 format;
+    guint32 italicAngle;
+    gint16  underlinePosition;
+    gint16  underlineThickness;
+    guint32 isFixedPitch;
     void   *ptr;                        /* format-specific pointer */
 } tdata_post;
     
 
 /* allocate memory for a TT table */
-static byte *ttmalloc(uint32 nbytes)
+static guint8 *ttmalloc(guint32 nbytes)
 {
-    uint32 n; 
-    byte *res;
+    guint32 n; 
+    guint8 *res;
 
-    n = (nbytes + 3) & (uint32) ~3;
+    n = (nbytes + 3) & (guint32) ~3;
     res = malloc(n);
     assert(res != 0);
     bzero(res, n);
@@ -615,7 +622,7 @@ static void TrueTypeTableDispose_post(TrueTypeTable *_this)
 /* destructor vtable */
 
 static struct {
-    uint32 tag;
+    guint32 tag;
     void (*f)(TrueTypeTable *);
 } vtable1[] =
 {
@@ -631,7 +638,7 @@ static struct {
     
 };
 
-static int GetRawData_generic(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_generic(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     assert(_this != 0);
     assert(_this->data != 0);
@@ -644,25 +651,25 @@ static int GetRawData_generic(TrueTypeTable *_this, byte **ptr, uint32 *len, uin
 }
 
 
-static int GetRawData_head(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_head(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     *len = TABLESIZE_head;
-    *ptr = (byte *) _this->data;
+    *ptr = (guint8 *) _this->data;
     *tag = T_head;
     
     return TTCR_OK;
 }
 
-static int GetRawData_hhea(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_hhea(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     *len = TABLESIZE_hhea;
-    *ptr = (byte *) _this->data;
+    *ptr = (guint8 *) _this->data;
     *tag = T_hhea;
     
     return TTCR_OK;
 }
 
-static int GetRawData_loca(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_loca(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     tdata_loca *p;
 
@@ -679,21 +686,21 @@ static int GetRawData_loca(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
     return TTCR_OK;
 }
 
-static int GetRawData_maxp(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_maxp(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     *len = TABLESIZE_maxp;
-    *ptr = (byte *) _this->data;
+    *ptr = (guint8 *) _this->data;
     *tag = T_maxp;
     
     return TTCR_OK;
 }
 
-static int GetRawData_glyf(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_glyf(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
-    uint32 n, nbytes = 0;
+    guint32 n, nbytes = 0;
     list l = (list) _this->data;
-    /* uint16 curID = 0;    */               /* to check if glyph IDs are sequential and start from zero */
-    byte *p;
+    /* guint16 curID = 0;    */               /* to check if glyph IDs are sequential and start from zero */
+    guint8 *p;
 
     *ptr = NULL;
     *len = 0;
@@ -726,12 +733,12 @@ static int GetRawData_glyf(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
 }
 
 /* cmap packers */
-static byte *PackCmapType0(CmapSubTable *s, uint32 *length)
+static guint8 *PackCmapType0(CmapSubTable *s, guint32 *length)
 {
-    byte *ptr = smalloc(262);
-    byte *p = ptr + 6;
+    guint8 *ptr = smalloc(262);
+    guint8 *p = ptr + 6;
     int i, j;
-    uint16 g;
+    guint16 g;
 
     PutUInt16(0, ptr, 0, 1);
     PutUInt16(262, ptr, 2, 1);
@@ -741,10 +748,10 @@ static byte *PackCmapType0(CmapSubTable *s, uint32 *length)
         g = 0;
         for (j = 0; j < s->n; j++) {
             if (s->xc[j] == i) {
-                g = (uint16) s->xg[j];
+                g = (guint16) s->xg[j];
             }
         }
-        p[i] = (byte) g;
+        p[i] = (guint8) g;
     }
     *length = 262;
     return ptr;
@@ -752,30 +759,30 @@ static byte *PackCmapType0(CmapSubTable *s, uint32 *length)
             
 
 /* XXX it only handles Format 0 encoding tables */
-static byte *PackCmap(CmapSubTable *s, uint32 *length)
+static guint8 *PackCmap(CmapSubTable *s, guint32 *length)
 {
     return PackCmapType0(s, length);
 }
 
-static int GetRawData_cmap(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_cmap(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     table_cmap *t;
-    byte **subtables;
-    uint32 *sizes;            /* of subtables */
+    guint8 **subtables;
+    guint32 *sizes;            /* of subtables */
     int i;
-    uint32 tlen = 0;
-    uint32 l;
-    uint32 cmapsize;
-    byte *cmap;
-    uint32 coffset;
+    guint32 tlen = 0;
+    guint32 l;
+    guint32 cmapsize;
+    guint8 *cmap;
+    guint32 coffset;
 
     assert(_this != 0);
     t = (table_cmap *) _this->data;
     assert(t != 0);
     assert(t->n != 0);
 
-    subtables = scalloc(t->n, sizeof(byte *));
-    sizes = scalloc(t->n, sizeof(uint32));
+    subtables = scalloc(t->n, sizeof(guint8 *));
+    sizes = scalloc(t->n, sizeof(guint32));
 
     for (i = 0; i < t->n; i++) {
         subtables[i] = PackCmap(t->s+i, &l);
@@ -810,15 +817,15 @@ static int GetRawData_cmap(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
 }
 
 
-static int GetRawData_name(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_name(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     list l;
     NameRecord *nr;
-    int16 i=0, n;                          /* number of Name Records */
-    byte *name;
-    uint16 nameLen;
+    gint16 i=0, n;                          /* number of Name Records */
+    guint8 *name;
+    guint16 nameLen;
     int stringLen = 0;
-    byte *p1, *p2;
+    guint8 *p1, *p2;
 
     *ptr = NULL;
     *len = 0;
@@ -882,11 +889,11 @@ static int GetRawData_name(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
     return TTCR_OK;
 }
 
-static int GetRawData_post(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+static int GetRawData_post(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     tdata_post *p = (tdata_post *) _this->data;
-    byte *post = NULL;
-    uint32 postLen = 0;
+    guint8 *post = NULL;
+    guint32 postLen = 0;
     int ret;
 
     if (_this->rawdata) free(_this->rawdata);
@@ -917,8 +924,8 @@ static int GetRawData_post(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
     
 
 static struct {
-    uint32 tag;
-    int (*f)(TrueTypeTable *, byte **, uint32 *, uint32 *);
+    guint32 tag;
+    int (*f)(TrueTypeTable *, guint8 **, guint32 *, guint32 *);
 } vtable2[] =
 {
     {0,      GetRawData_generic},
@@ -949,9 +956,9 @@ static struct {
  *
  */
 
-TrueTypeTable *TrueTypeTableNew(uint32 tag,
-                                uint32 nbytes,
-                                byte *ptr)
+TrueTypeTable *TrueTypeTableNew(guint32 tag,
+                                guint32 nbytes,
+                                guint8 *ptr)
 {
     TrueTypeTable *table;
     tdata_generic *pdata;
@@ -974,16 +981,16 @@ TrueTypeTable *TrueTypeTableNew(uint32 tag,
     return table;
 }
     
-TrueTypeTable *TrueTypeTableNew_head(uint32 fontRevision,
-                                     uint16 flags,
-                                     uint16 unitsPerEm,
-                                     byte  *created,
-                                     uint16 macStyle,
-                                     uint16 lowestRecPPEM,
-                                     int16  fontDirectionHint)
+TrueTypeTable *TrueTypeTableNew_head(guint32 fontRevision,
+                                     guint16 flags,
+                                     guint16 unitsPerEm,
+                                     guint8  *created,
+                                     guint16 macStyle,
+                                     guint16 lowestRecPPEM,
+                                     gint16  fontDirectionHint)
 {
     TrueTypeTable *table;
-    byte *ptr;
+    guint8 *ptr;
 
     assert(created != 0);
 
@@ -1010,14 +1017,14 @@ TrueTypeTable *TrueTypeTableNew_head(uint32 fontRevision,
     return table;
 }
 
-TrueTypeTable *TrueTypeTableNew_hhea(int16  ascender,
-                                     int16  descender,
-                                     int16  linegap,
-                                     int16  caretSlopeRise,
-                                     int16  caretSlopeRun)
+TrueTypeTable *TrueTypeTableNew_hhea(gint16  ascender,
+                                     gint16  descender,
+                                     gint16  linegap,
+                                     gint16  caretSlopeRise,
+                                     gint16  caretSlopeRun)
 {
     TrueTypeTable *table;
-    byte *ptr;
+    guint8 *ptr;
 
     table  = smalloc(sizeof(TrueTypeTable));
     ptr  = ttmalloc(TABLESIZE_hhea);
@@ -1056,7 +1063,7 @@ TrueTypeTable *TrueTypeTableNew_loca(void)
     return table;
 }
 
-TrueTypeTable *TrueTypeTableNew_maxp(byte *maxp, int size)
+TrueTypeTable *TrueTypeTableNew_maxp(guint8 *maxp, int size)
 {
     TrueTypeTable *table = smalloc(sizeof(TrueTypeTable));
     table->data = ttmalloc(TABLESIZE_maxp);
@@ -1151,11 +1158,11 @@ TrueTypeTable *TrueTypeTableNew_name(int n, NameRecord *nr)
     return table;
 }
 
-TrueTypeTable *TrueTypeTableNew_post(uint32 format,
-                                     uint32 italicAngle,
-                                     int16 underlinePosition,
-                                     int16 underlineThickness,
-                                     uint32 isFixedPitch)
+TrueTypeTable *TrueTypeTableNew_post(guint32 format,
+                                     guint32 italicAngle,
+                                     gint16 underlinePosition,
+                                     gint16 underlineThickness,
+                                     guint32 isFixedPitch)
 {
     TrueTypeTable *table;
     tdata_post *post;
@@ -1198,7 +1205,7 @@ void TrueTypeTableDispose(TrueTypeTable *_this)
     assert(!"Unknown TrueType table.\n");
 }
 
-int GetRawData(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
+int GetRawData(TrueTypeTable *_this, guint8 **ptr, guint32 *len, guint32 *tag)
 {
     /* XXX do a binary search */
     int i;
@@ -1225,7 +1232,7 @@ int GetRawData(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
     return TTCR_UNKNOWN;
 }
     
-void cmapAdd(TrueTypeTable *table, uint32 id, uint32 c, uint32 g)
+void cmapAdd(TrueTypeTable *table, guint32 id, guint32 c, guint32 g)
 {
     int i, found;
     table_cmap *t;
@@ -1270,17 +1277,17 @@ void cmapAdd(TrueTypeTable *table, uint32 id, uint32 c, uint32 g)
         s[i].id = id;
         s[i].n = 0;
         s[i].m = CMAP_PAIR_INIT;
-        s[i].xc = scalloc(CMAP_PAIR_INIT, sizeof(uint32));
-        s[i].xg = scalloc(CMAP_PAIR_INIT, sizeof(uint32));
+        s[i].xc = scalloc(CMAP_PAIR_INIT, sizeof(guint32));
+        s[i].xg = scalloc(CMAP_PAIR_INIT, sizeof(guint32));
     }
 
     if (s[i].n == s[i].m) {
-        uint32 *tmp1 = scalloc(s[i].m + CMAP_PAIR_INCR, sizeof(uint32));
-        uint32 *tmp2 = scalloc(s[i].m + CMAP_PAIR_INCR, sizeof(uint32));
+        guint32 *tmp1 = scalloc(s[i].m + CMAP_PAIR_INCR, sizeof(guint32));
+        guint32 *tmp2 = scalloc(s[i].m + CMAP_PAIR_INCR, sizeof(guint32));
         assert(tmp1 != 0);
         assert(tmp2 != 0);
-        memcpy(tmp1, s[i].xc, sizeof(uint32) * s[i].m);
-        memcpy(tmp2, s[i].xg, sizeof(uint32) * s[i].m);
+        memcpy(tmp1, s[i].xc, sizeof(guint32) * s[i].m);
+        memcpy(tmp2, s[i].xg, sizeof(guint32) * s[i].m);
         s[i].m += CMAP_PAIR_INCR;
         free(s[i].xc);
         free(s[i].xg);
@@ -1293,10 +1300,10 @@ void cmapAdd(TrueTypeTable *table, uint32 id, uint32 c, uint32 g)
     s[i].n++;
 }
 
-uint32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, TrueTypeFont *fnt)
+guint32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, TrueTypeFont *fnt)
 {
     list l;
-    uint32 currentID;
+    guint32 currentID;
     int ret, n, ncomponents;
     list glyphlist;
     GlyphData *gd;
@@ -1324,7 +1331,7 @@ uint32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, TrueTypeFont *fnt)
         listPositionAt(glyphlist, 1);       /* glyphData->glyphID is always the first glyph on the list */
         do {
             int found = 0;
-            currentID = (uint32) listCurrent(glyphlist);
+            currentID = (guint32) listCurrent(glyphlist);
             /* XXX expensive! should be rewritten with sorted arrays! */
             listToFirst(l);
             do {
@@ -1346,7 +1353,7 @@ uint32 glyfAdd(TrueTypeTable *table, GlyphData *glyphdata, TrueTypeFont *fnt)
     return ret;
 }
 
-uint32 glyfCount(const TrueTypeTable *table)
+guint32 glyfCount(const TrueTypeTable *table)
 {
     assert(table != 0);
     assert(table->tag == T_glyf);
@@ -1366,7 +1373,7 @@ void nameAdd(TrueTypeTable *table, NameRecord *nr)
     listAppend(l, NameRecordNewCopy(nr));
 }
                
-static TrueTypeTable *FindTable(TrueTypeCreator *tt, uint32 tag)
+static TrueTypeTable *FindTable(TrueTypeCreator *tt, guint32 tag)
 {
     if (listIsEmpty(tt->tables)) return NULL;
 
@@ -1400,23 +1407,23 @@ static void ProcessTables(TrueTypeCreator *tt)
 {
     TrueTypeTable *glyf, *loca, *head, *maxp, *hhea;
     list glyphlist;
-    uint32 nGlyphs, locaLen = 0, glyfLen = 0;
-    int16 xMin = 0, yMin = 0, xMax = 0, yMax = 0;
+    guint32 nGlyphs, locaLen = 0, glyfLen = 0;
+    gint16 xMin = 0, yMin = 0, xMax = 0, yMax = 0;
     int i = 0;
-    int16 indexToLocFormat;
-    byte *glyfPtr, *locaPtr, *hmtxPtr, *hheaPtr;
-    uint32 hmtxSize;
-    byte *p1, *p2;
-    uint16 maxPoints = 0, maxContours = 0, maxCompositePoints = 0, maxCompositeContours = 0;
+    gint16 indexToLocFormat;
+    guint8 *glyfPtr, *locaPtr, *hmtxPtr, *hheaPtr;
+    guint32 hmtxSize;
+    guint8 *p1, *p2;
+    guint16 maxPoints = 0, maxContours = 0, maxCompositePoints = 0, maxCompositeContours = 0;
     TTSimpleGlyphMetrics *met;
     int nlsb = 0;
-    uint32 *gid;                        /* array of old glyphIDs */
+    guint32 *gid;                        /* array of old glyphIDs */
 
     glyf = FindTable(tt, T_glyf);
     glyphlist = (list) glyf->data;
     nGlyphs = listCount(glyphlist);
     assert(nGlyphs != 0);
-    gid = scalloc(nGlyphs, sizeof(uint32));
+    gid = scalloc(nGlyphs, sizeof(guint32));
 
     RemoveTable(tt, T_loca);
     RemoveTable(tt, T_hmtx);
@@ -1426,7 +1433,7 @@ static void ProcessTables(TrueTypeCreator *tt)
     listToFirst(glyphlist);
     do {
         GlyphData *gd = (GlyphData *) listCurrent(glyphlist);
-        int16 z;
+        gint16 z;
         glyfLen += gd->nbytes;
         /* XXX if (gd->nbytes & 1) glyfLen++; */
 
@@ -1476,8 +1483,8 @@ static void ProcessTables(TrueTypeCreator *tt)
         GlyphData *gd = (GlyphData *) listCurrent(glyphlist);
         
         if (gd->compflag) {                       /* re-number all components */
-            uint16 flags, index;
-            byte *ptr = gd->ptr + 10;
+            guint16 flags, index;
+            guint8 *ptr = gd->ptr + 10;
             do {
                 int j;
                 flags = GetUInt16(ptr, 0, 1);
@@ -1490,7 +1497,7 @@ static void ProcessTables(TrueTypeCreator *tt)
                 }
                 /* printf("X: %d -> %d.\n", index, j); */
 
-                PutUInt16((uint16) j, ptr, 2, 1);
+                PutUInt16((guint16) j, ptr, 2, 1);
 
                 ptr += 4;
 
@@ -1576,7 +1583,7 @@ static void ProcessTables(TrueTypeCreator *tt)
      * Generate an htmx table and update hhea table
      */
     hhea = FindTable(tt, T_hhea); assert(hhea != 0);
-    hheaPtr = (byte *) hhea->data;
+    hheaPtr = (guint8 *) hhea->data;
     if (nGlyphs > 2) {
         for (i = nGlyphs - 1; i > 0; i--) {
             if (met[i].adv != met[i-1].adv) break;
@@ -1608,7 +1615,7 @@ static void ProcessTables(TrueTypeCreator *tt)
 int main(void)
 {
     TrueTypeCreator *ttcr;
-    byte *t1, *t2, *t3, *t4, *t5, *t6, *t7;
+    guint8 *t1, *t2, *t3, *t4, *t5, *t6, *t7;
 
     TrueTypeCreatorNewEmpty(mkTag('t','r','u','e'), &ttcr);
 
